@@ -38,6 +38,4 @@ class UserRepository(UserRepositoryPort, BaseRepository):
         )
 
     def remove_user_role(self, user: User, role: UserRole):
-        """Remove user role."""
         user.user_roles.remove(role)
-        self.session.commit()
