@@ -25,18 +25,19 @@ class CreateOrUpdateUserUseCase(UseCasePort):
     def keep_keys(self, keys: list) -> UserTenantData:
         return {k: v for k, v in self.user_tenant_data.items() if k in keys}
 
-    def check_if_user_exists(self) -> Union[User, bool]:
-        user = self.users_unit_of_work.user_repository.get_or_none(
-            username=self.user_tenant_data.get("username")
-        )
-        return user or False
-
     def execute(self, data: UserTenantData) -> User:
         self.user_tenant_data = data
         user_data = self.keep_keys(user_data_keys)
-        user = self.check_if_user_exists()
-        return (
-            self.users_unit_of_work.user_repository.update_record(user, **user_data)
-            if user
-            else self.users_unit_of_work.user_repository.create(**user_data)
-        )
+
+        with self.users_unit_of_work as uow:
+            user = uow.user_repository.get_or_none(
+                username=self.user_tenant_data.get("username")
+            )
+
+            if user:
+                user = uow.user_repository.update_record(user, **user_data)
+            else:
+                user = uow.user_repository.create(**user_data)
+
+            uow.commit()
+            return user
